@@ -17,9 +17,9 @@ extern void setzero();
 /* static int lfindex[MXIDIM];
    static double M[(1+MXIDIM)*MXIDIM*MXIDIM]; */
 
-void monte(f,ll,ur,d,res,n)
-int (*f)(), d, n;
-double *ll, *ur, *res;
+void monte(int (*f)(), double *ll, double *ur, int d, double *res, int n)
+/*int (*f)(), d, n;
+double *ll, *ur, *res;*/
 { int i, j, nr=0;
   double z, x[MXIDIM], tres[MXRESULT];
 
